@@ -23,6 +23,7 @@ import org.apache.parquet.bytes.BytesInput;
 import org.apache.parquet.column.Encoding;
 import org.apache.parquet.column.statistics.SizeStatistics;
 import org.apache.parquet.column.statistics.Statistics;
+import org.apache.parquet.column.statistics.geospatial.GeospatialStatistics;
 
 /**
  * a writer for all the pages of a given column chunk
@@ -86,6 +87,7 @@ public interface PageWriter extends AutoCloseable {
    * @param valuesEncoding values encoding
    * @throws IOException
    */
+  @Deprecated
   default void writePage(
       BytesInput bytesInput,
       int valueCount,
@@ -99,6 +101,33 @@ public interface PageWriter extends AutoCloseable {
     throw new UnsupportedOperationException("writePage with SizeStatistics is not implemented");
   }
 
+  /**
+   * writes a single page
+   * @param bytesInput the bytes for the page
+   * @param valueCount the number of values in that page
+   * @param rowCount the number of rows in that page
+   * @param statistics the statistics for that page
+   * @param sizeStatistics the size statistics for that page
+   * @param geospatialStatistics the geospatial statistics for that page
+   * @param rlEncoding repetition level encoding
+   * @param dlEncoding definition level encoding
+   * @param valuesEncoding values encoding
+   * @throws IOException
+   */
+  default void writePage(
+      BytesInput bytesInput,
+      int valueCount,
+      int rowCount,
+      Statistics<?> statistics,
+      SizeStatistics sizeStatistics,
+      GeospatialStatistics geospatialStatistics,
+      Encoding rlEncoding,
+      Encoding dlEncoding,
+      Encoding valuesEncoding)
+      throws IOException {
+    throw new UnsupportedOperationException("writePage with GeospatialStatistics is not implemented");
+  }
+
   /**
    * writes a single page in the new format
    *
@@ -136,6 +165,7 @@ public interface PageWriter extends AutoCloseable {
    * @param sizeStatistics optional size stats for this page
    * @throws IOException if there is an exception while writing page data
    */
+  @Deprecated
   default void writePageV2(
       int rowCount,
       int nullCount,
@@ -150,6 +180,34 @@ public interface PageWriter extends AutoCloseable {
     throw new UnsupportedOperationException("writePageV2 with SizeStatistics is not implemented");
   }
 
+  /**
+   * writes a single page in the new format
+   * @param rowCount the number of rows in this page
+   * @param nullCount the number of null values (out of valueCount)
+   * @param valueCount the number of values in that page (there could be multiple values per row for repeated fields)
+   * @param repetitionLevels the repetition levels encoded in RLE without any size header
+   * @param definitionLevels the definition levels encoded in RLE without any size header
+   * @param dataEncoding the encoding for the data
+   * @param data the data encoded with dataEncoding
+   * @param statistics optional stats for this page
+   * @param sizeStatistics optional size stats for this page
+   * @throws IOException if there is an exception while writing page data
+   */
+  default void writePageV2(
+      int rowCount,
+      int nullCount,
+      int valueCount,
+      BytesInput repetitionLevels,
+      BytesInput definitionLevels,
+      Encoding dataEncoding,
+      BytesInput data,
+      Statistics<?> statistics,
+      SizeStatistics sizeStatistics,
+      GeospatialStatistics geospatialStatistics)
+      throws IOException {
+    throw new UnsupportedOperationException("writePageV2 with GeospatialStatistics is not implemented");
+  }
+
   /**
    * @return the current size used in the memory buffer for that column chunk
    */
