@@ -20,19 +20,21 @@ package org.apache.parquet.bytes;
 
 import java.io.ByteArrayOutputStream;
 import java.io.DataInputStream;
+import java.io.EOFException;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.nio.ByteBuffer;
+import java.nio.ByteOrder;
 import java.nio.channels.Channels;
+import java.nio.channels.ReadableByteChannel;
 import java.nio.channels.WritableByteChannel;
 import java.util.Arrays;
 import java.util.List;
-
+import java.util.function.Consumer;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-
 /**
  * A source of bytes capable of writing itself to an output.
  * A BytesInput should be consumed right away.
@@ -41,12 +43,13 @@ import org.slf4j.LoggerFactory;
  * subsequent BytesInput reads from the stream will be incorrect
  * if the previous has not been consumed.
  */
-abstract public class BytesInput {
+public abstract class BytesInput {
   private static final Logger LOG = LoggerFactory.getLogger(BytesInput.class);
   private static final EmptyBytesInput EMPTY_BYTES_INPUT = new EmptyBytesInput();
 
   /**
    * logically concatenate the provided inputs
+   *
    * @param inputs the inputs to concatenate
    * @return a concatenated input
    */
@@ -56,6 +59,7 @@ abstract public class BytesInput {
 
   /**
    * logically concatenate the provided inputs
+   *
    * @param inputs the inputs to concatenate
    * @return a concatenated input
    */
@@ -64,7 +68,7 @@ abstract public class BytesInput {
   }
 
   /**
-   * @param in an input stream
+   * @param in    an input stream
    * @param bytes number of bytes to read
    * @return a BytesInput that will read that number of bytes from the stream
    */
@@ -74,8 +78,7 @@ abstract public class BytesInput {
 
   /**
    * @param buffer
-   * @param length
-   *          number of bytes to read
+   * @param length number of bytes to read
    * @return a BytesInput that will read the given bytes from the ByteBuffer
    * @deprecated Will be removed in 2.0.0
    */
@@ -111,13 +114,12 @@ abstract public class BytesInput {
   }
 
   /**
-   *
    * @param in a byte array
    * @return a Bytes input that will write the given bytes
    */
   public static BytesInput from(byte[] in) {
     LOG.debug("BytesInput from array of {} bytes", in.length);
-    return new ByteArrayBytesInput(in, 0 , in.length);
+    return new ByteArrayBytesInput(in, 0, in.length);
   }
 
   public static BytesInput from(byte[] in, int offset, int length) {
@@ -142,7 +144,6 @@ abstract public class BytesInput {
   }
 
   /**
-   *
    * @param intValue the int to write
    * @return a ByteInput that contains the int value as a variable-length zig-zag encoded int
    */
@@ -160,7 +161,6 @@ abstract public class BytesInput {
   }
 
   /**
-   *
    * @param longValue the long to write
    * @return a ByteInput that contains the long value as a variable-length zig-zag encoded long
    */
@@ -194,51 +194,143 @@ abstract public class BytesInput {
 
   /**
    * copies the input into a new byte array
+   *
    * @param bytesInput a BytesInput
    * @return a copy of the BytesInput
    * @throws IOException if there is an exception when reading bytes from the BytesInput
+   * @deprecated Use {@link #copy(ByteBufferAllocator, Consumer)} instead
    */
+  @Deprecated
   public static BytesInput copy(BytesInput bytesInput) throws IOException {
     return from(bytesInput.toByteArray());
   }
 
   /**
    * writes the bytes into a stream
+   *
    * @param out an output stream
    * @throws IOException if there is an exception writing
    */
-  abstract public void writeAllTo(OutputStream out) throws IOException;
+  public abstract void writeAllTo(OutputStream out) throws IOException;
+
+  /**
+   * For internal use only. It is expected that the buffer is large enough to fit the content of this {@link BytesInput}
+   * object.
+   */
+  abstract void writeInto(ByteBuffer buffer);
 
   /**
-   *
    * @return a new byte array materializing the contents of this input
    * @throws IOException if there is an exception reading
+   * @deprecated Use {@link #toByteBuffer(ByteBufferAllocator, Consumer)}
    */
+  @Deprecated
   public byte[] toByteArray() throws IOException {
     long size = size();
     if (size > Integer.MAX_VALUE) {
-      throw new IOException("Page size, " + size + ", is larger than allowed " + Integer.MAX_VALUE + "." +
-        " Usually caused by a Parquet writer writing too big column chunks on encountering highly skewed dataset." +
-        " Please set page.size.row.check.max to a lower value on the writer, default value is 10000." +
-        " You can try setting it to " + (10000 / (size / Integer.MAX_VALUE)) + " or lower.");
+      throw new IOException("Page size, " + size + ", is larger than allowed " + Integer.MAX_VALUE + "."
+          + " Usually caused by a Parquet writer writing too big column chunks on encountering highly skewed dataset."
+          + " Please set page.size.row.check.max to a lower value on the writer, default value is 10000."
+          + " You can try setting it to "
+          + (10000 / (size / Integer.MAX_VALUE)) + " or lower.");
     }
-    BAOS baos = new BAOS((int)size());
+    BAOS baos = new BAOS((int) size());
     this.writeAllTo(baos);
-    LOG.debug("converted {} to byteArray of {} bytes", size() , baos.size());
+    LOG.debug("converted {} to byteArray of {} bytes", size(), baos.size());
     return baos.getBuf();
   }
 
   /**
-   *
    * @return a new ByteBuffer materializing the contents of this input
    * @throws IOException if there is an exception reading
+   * @deprecated Use {@link #toByteBuffer(ByteBufferAllocator, Consumer)}
    */
+  @Deprecated
   public ByteBuffer toByteBuffer() throws IOException {
     return ByteBuffer.wrap(toByteArray());
   }
 
   /**
+   * Copies the content of this {@link BytesInput} object to a newly created {@link ByteBuffer} and returns it wrapped
+   * in a {@link BytesInput} object.
    *
+   * <strong>The data content shall be able to be fit in a {@link ByteBuffer} object!</strong> (In case of the size of
+   * this {@link BytesInput} object cannot fit in an {@code int}, an {@link ArithmeticException} will be thrown. The
+   * {@code allocator} might throw an {@link OutOfMemoryError} if it is unable to allocate the required
+   * {@link ByteBuffer}.)
+   *
+   * @param allocator the allocator to be used for creating the new {@link ByteBuffer} object
+   * @param callback  the callback called with the newly created {@link ByteBuffer} object; to be used for make it
+   *                  released at the proper time
+   * @return the newly created {@link BytesInput} object wrapping the copied content of the specified one
+   */
+  public BytesInput copy(ByteBufferAllocator allocator, Consumer<ByteBuffer> callback) {
+    ByteBuffer buf = allocator.allocate(Math.toIntExact(size()));
+    callback.accept(buf);
+    writeInto(buf);
+    buf.flip();
+    return BytesInput.from(buf);
+  }
+
+  /**
+   * Similar to {@link #copy(ByteBufferAllocator, Consumer)} where the allocator and the callback are in the specified
+   * {@link ByteBufferReleaser}.
+   */
+  public BytesInput copy(ByteBufferReleaser releaser) {
+    return copy(releaser.allocator, releaser::releaseLater);
+  }
+
+  /**
+   * Returns a {@link ByteBuffer} object referencing the data behind this {@link BytesInput} object. It may create a new
+   * {@link ByteBuffer} object if this {@link BytesInput} is not backed by a single {@link ByteBuffer}. In the latter
+   * case the specified {@link ByteBufferAllocator} object will be used. In case of allocation the specified callback
+   * will be invoked so the release of the newly allocated {@link ByteBuffer} object can be released at a proper time.
+   *
+   * <strong>The data content shall be able to be fit in a {@link ByteBuffer} object!</strong> (In case of the size of
+   * this {@link BytesInput} object cannot fit in an {@code int}, an {@link ArithmeticException} will be thrown. The
+   * {@code allocator} might throw an {@link OutOfMemoryError} if it is unable to allocate the required
+   * {@link ByteBuffer}.)
+   *
+   * @param allocator the {@link ByteBufferAllocator} to be used for potentially allocating a new {@link ByteBuffer}
+   *                  object
+   * @param callback  the callback to be called with the new {@link ByteBuffer} object potentially allocated
+   * @return the {@link ByteBuffer} object with the data content of this {@link BytesInput} object. (Might be a copy of
+   * the content or directly referencing the same memory as this {@link BytesInput} object.)
+   */
+  public ByteBuffer toByteBuffer(ByteBufferAllocator allocator, Consumer<ByteBuffer> callback) {
+    ByteBuffer buf = getInternalByteBuffer();
+    // The internal buffer should be direct iff the allocator is direct as well but let's be sure
+    if (buf == null || buf.isDirect() != allocator.isDirect()) {
+      buf = allocator.allocate(Math.toIntExact(size()));
+      callback.accept(buf);
+      writeInto(buf);
+      buf.flip();
+    }
+    return buf;
+  }
+
+  /**
+   * Similar to {@link #toByteBuffer(ByteBufferAllocator, Consumer)} where the allocator and the callback are in the
+   * specified {@link ByteBufferReleaser}.
+   */
+  public ByteBuffer toByteBuffer(ByteBufferReleaser releaser) {
+    return toByteBuffer(releaser.allocator, releaser::releaseLater);
+  }
+
+  /**
+   * For internal use only.
+   * <p>
+   * Returns a {@link ByteBuffer} object referencing to the internal data of this {@link BytesInput} without copying if
+   * applicable. If it is not possible (because there are multiple {@link ByteBuffer}s internally or cannot be
+   * referenced as a {@link ByteBuffer}), {@code null} value will be returned.
+   *
+   * @return the internal data of this {@link BytesInput} or {@code null}
+   */
+  ByteBuffer getInternalByteBuffer() {
+    return null;
+  }
+
+  /**
    * @return a new InputStream materializing the contents of this input
    * @throws IOException if there is an exception reading
    */
@@ -247,10 +339,9 @@ abstract public class BytesInput {
   }
 
   /**
-   *
    * @return the size in bytes that would be written
    */
-  abstract public long size();
+  public abstract long size();
 
   private static final class BAOS extends ByteArrayOutputStream {
     private BAOS(int size) {
@@ -280,6 +371,28 @@ abstract public class BytesInput {
       out.write(this.toByteArray());
     }
 
+    @Override
+    void writeInto(ByteBuffer buffer) {
+      try {
+        // Needs a duplicate buffer to set the correct limit (we do not want to over-read the stream)
+        ByteBuffer workBuf = buffer.duplicate();
+        int pos = buffer.position();
+        workBuf.limit(pos + byteCount);
+        ReadableByteChannel channel = Channels.newChannel(in);
+        int remaining = byteCount;
+        while (remaining > 0) {
+          int bytesRead = channel.read(workBuf);
+          if (bytesRead < 0) {
+            throw new EOFException("Reached the end of stream with " + remaining + " bytes left to read");
+          }
+          remaining -= bytesRead;
+        }
+        buffer.position(pos + byteCount);
+      } catch (IOException e) {
+        throw new RuntimeException("Exception occurred during reading input stream", e);
+      }
+    }
+
     public byte[] toByteArray() throws IOException {
       LOG.debug("read all {} bytes", byteCount);
       byte[] buf = new byte[byteCount];
@@ -291,7 +404,6 @@ abstract public class BytesInput {
     public long size() {
       return byteCount;
     }
-
   }
 
   private static class SequenceBytesIn extends BytesInput {
@@ -321,11 +433,22 @@ abstract public class BytesInput {
       }
     }
 
+    @Override
+    void writeInto(ByteBuffer buffer) {
+      for (BytesInput input : inputs) {
+        input.writeInto(buffer);
+      }
+    }
+
+    @Override
+    ByteBuffer getInternalByteBuffer() {
+      return inputs.size() == 1 ? inputs.get(0).getInternalByteBuffer() : null;
+    }
+
     @Override
     public long size() {
       return size;
     }
-
   }
 
   private static class IntBytesInput extends BytesInput {
@@ -341,15 +464,22 @@ abstract public class BytesInput {
       BytesUtils.writeIntLittleEndian(out, intValue);
     }
 
-    public ByteBuffer toByteBuffer() throws IOException {
-      return ByteBuffer.allocate(4).putInt(0, intValue);
+    @Override
+    void writeInto(ByteBuffer buffer) {
+      buffer.order(ByteOrder.LITTLE_ENDIAN).putInt(intValue);
+    }
+
+    public ByteBuffer toByteBuffer() {
+      ByteBuffer buf = ByteBuffer.allocate(4);
+      writeInto(buf);
+      buf.flip();
+      return buf;
     }
 
     @Override
     public long size() {
       return 4;
     }
-
   }
 
   private static class UnsignedVarIntBytesInput extends BytesInput {
@@ -365,9 +495,20 @@ abstract public class BytesInput {
       BytesUtils.writeUnsignedVarInt(intValue, out);
     }
 
-    public ByteBuffer toByteBuffer() throws IOException {
+    @Override
+    void writeInto(ByteBuffer buffer) {
+      try {
+        BytesUtils.writeUnsignedVarInt(intValue, buffer);
+      } catch (IOException e) {
+        // It does not actually throw an I/O exception, but we cannot remove throws for compatibility
+        throw new RuntimeException(e);
+      }
+    }
+
+    public ByteBuffer toByteBuffer() {
       ByteBuffer ret = ByteBuffer.allocate((int) size());
-      BytesUtils.writeUnsignedVarInt(intValue, ret);
+      writeInto(ret);
+      ret.flip();
       return ret;
     }
 
@@ -391,6 +532,11 @@ abstract public class BytesInput {
       BytesUtils.writeUnsignedVarLong(longValue, out);
     }
 
+    @Override
+    void writeInto(ByteBuffer buffer) {
+      BytesUtils.writeUnsignedVarLong(longValue, buffer);
+    }
+
     @Override
     public long size() {
       int s = (70 - Long.numberOfLeadingZeros(longValue)) / 7;
@@ -401,7 +547,11 @@ abstract public class BytesInput {
   private static class EmptyBytesInput extends BytesInput {
 
     @Override
-    public void writeAllTo(OutputStream out) throws IOException {
+    public void writeAllTo(OutputStream out) throws IOException {}
+
+    @Override
+    void writeInto(ByteBuffer buffer) {
+      // no-op
     }
 
     @Override
@@ -412,7 +562,6 @@ abstract public class BytesInput {
     public ByteBuffer toByteBuffer() throws IOException {
       return ByteBuffer.allocate(0);
     }
-
   }
 
   private static class CapacityBAOSBytesInput extends BytesInput {
@@ -428,11 +577,20 @@ abstract public class BytesInput {
       arrayOut.writeTo(out);
     }
 
+    @Override
+    void writeInto(ByteBuffer buffer) {
+      arrayOut.writeInto(buffer);
+    }
+
+    @Override
+    ByteBuffer getInternalByteBuffer() {
+      return arrayOut.getInternalByteBuffer();
+    }
+
     @Override
     public long size() {
       return arrayOut.size();
     }
-
   }
 
   private static class BAOSBytesInput extends BytesInput {
@@ -448,11 +606,15 @@ abstract public class BytesInput {
       arrayOut.writeTo(out);
     }
 
+    @Override
+    void writeInto(ByteBuffer buffer) {
+      buffer.put(arrayOut.toByteArray());
+    }
+
     @Override
     public long size() {
       return arrayOut.size();
     }
-
   }
 
   private static class ByteArrayBytesInput extends BytesInput {
@@ -472,6 +634,11 @@ abstract public class BytesInput {
       out.write(in, offset, length);
     }
 
+    @Override
+    void writeInto(ByteBuffer buffer) {
+      buffer.put(in, offset, length);
+    }
+
     public ByteBuffer toByteBuffer() throws IOException {
       return java.nio.ByteBuffer.wrap(in, offset, length);
     }
@@ -480,7 +647,6 @@ abstract public class BytesInput {
     public long size() {
       return length;
     }
-
   }
 
   private static class BufferListBytesInput extends BytesInput {
@@ -504,6 +670,13 @@ abstract public class BytesInput {
       }
     }
 
+    @Override
+    void writeInto(ByteBuffer target) {
+      for (ByteBuffer buffer : buffers) {
+        target.put(buffer.duplicate());
+      }
+    }
+
     @Override
     public ByteBufferInputStream toInputStream() {
       return ByteBufferInputStream.wrap(buffers);
@@ -527,6 +700,16 @@ abstract public class BytesInput {
       Channels.newChannel(out).write(buffer.duplicate());
     }
 
+    @Override
+    void writeInto(ByteBuffer target) {
+      target.put(buffer.duplicate());
+    }
+
+    @Override
+    ByteBuffer getInternalByteBuffer() {
+      return buffer.slice();
+    }
+
     @Override
     public ByteBufferInputStream toInputStream() {
       return ByteBufferInputStream.wrap(buffer);
@@ -536,5 +719,10 @@ abstract public class BytesInput {
     public long size() {
       return buffer.remaining();
     }
+
+    @Override
+    public ByteBuffer toByteBuffer() throws IOException {
+      return buffer.slice();
+    }
   }
 }
