@@ -609,6 +609,17 @@ public class ParquetWriter<T> implements Closeable {
       return self();
     }
 
+    /**
+     * Sets the Parquet format row group row count limit used by the constructed writer.
+     *
+     * @param rowCount limit for the number of rows stored in a row group
+     * @return this builder for method chaining
+     */
+    public SELF withRowGroupRowCountLimit(int rowCount) {
+      encodingPropsBuilder.withRowGroupRowCountLimit(rowCount);
+      return self();
+    }
+
     /**
      * Sets the Parquet format page row count limit used by the constructed writer.
      *
@@ -894,6 +905,54 @@ public class ParquetWriter<T> implements Closeable {
       return self();
     }
 
+    /**
+     * Sets the statistics enabled/disabled for the specified column. All column statistics are enabled by default.
+     *
+     * @param columnPath the path of the column (dot-string)
+     * @param enabled    whether to write calculate statistics for the column
+     * @return this builder for method chaining
+     */
+    public SELF withStatisticsEnabled(String columnPath, boolean enabled) {
+      encodingPropsBuilder.withStatisticsEnabled(columnPath, enabled);
+      return self();
+    }
+
+    /**
+     * Sets whether statistics are enabled globally. When disabled, statistics will not be collected
+     * for any column unless explicitly enabled for specific columns.
+     *
+     * @param enabled whether to collect statistics globally
+     * @return this builder for method chaining
+     */
+    public SELF withStatisticsEnabled(boolean enabled) {
+      encodingPropsBuilder.withStatisticsEnabled(enabled);
+      return self();
+    }
+
+    /**
+     * Sets the size statistics enabled/disabled for the specified column. All column size statistics are enabled by default.
+     *
+     * @param columnPath the path of the column (dot-string)
+     * @param enabled    whether to collect size statistics for the column
+     * @return this builder for method chaining
+     */
+    public SELF withSizeStatisticsEnabled(String columnPath, boolean enabled) {
+      encodingPropsBuilder.withSizeStatisticsEnabled(columnPath, enabled);
+      return self();
+    }
+
+    /**
+     * Sets whether size statistics are enabled globally. When disabled, size statistics will not be collected
+     * for any column unless explicitly enabled for specific columns.
+     *
+     * @param enabled whether to collect size statistics globally
+     * @return this builder for method chaining
+     */
+    public SELF withSizeStatisticsEnabled(boolean enabled) {
+      encodingPropsBuilder.withSizeStatisticsEnabled(enabled);
+      return self();
+    }
+
     /**
      * Build a {@link ParquetWriter} with the accumulated configuration.
      *
@@ -908,33 +967,21 @@ public class ParquetWriter<T> implements Closeable {
       if (codecFactory == null) {
         codecFactory = new CodecFactory(conf, encodingProps.getPageSizeThreshold());
       }
-      if (file != null) {
-        return new ParquetWriter<>(
-            file,
-            mode,
-            getWriteSupport(conf),
-            codecName,
-            codecFactory,
-            rowGroupSize,
-            enableValidation,
-            conf,
-            maxPaddingSize,
-            encodingProps,
-            encryptionProperties);
-      } else {
-        return new ParquetWriter<>(
-            HadoopOutputFile.fromPath(path, ConfigurationUtil.createHadoopConfiguration(conf)),
-            mode,
-            getWriteSupport(conf),
-            codecName,
-            codecFactory,
-            rowGroupSize,
-            enableValidation,
-            conf,
-            maxPaddingSize,
-            encodingProps,
-            encryptionProperties);
-      }
+
+      return new ParquetWriter<>(
+          (file != null)
+              ? file
+              : HadoopOutputFile.fromPath(path, ConfigurationUtil.createHadoopConfiguration(conf)),
+          mode,
+          getWriteSupport(conf),
+          codecName,
+          codecFactory,
+          rowGroupSize,
+          enableValidation,
+          conf,
+          maxPaddingSize,
+          encodingProps,
+          encryptionProperties);
     }
   }
 }
