@@ -132,7 +132,7 @@ public class TestParquetFileWriter {
 
   private static final Logger LOG = LoggerFactory.getLogger(TestParquetFileWriter.class);
 
-  private static final MessageType SCHEMA = MessageTypeParser.parseMessageType("" + "message m {"
+  private static final MessageType SCHEMA = MessageTypeParser.parseMessageType("message m {"
       + "  required group a {"
       + "    required binary b;"
       + "  }"
@@ -156,8 +156,6 @@ public class TestParquetFileWriter {
               Types.required(PrimitiveTypeName.BINARY).named("test_binary"))
           .build();
 
-  private String writeSchema;
-
   @Rule
   public final TemporaryFolder temp = new TemporaryFolder();
 
@@ -513,15 +511,15 @@ public class TestParquetFileWriter {
 
     w.startColumn(C1, 6, CODEC);
     long c1Starts = w.getPos();
-    w.writeDataPageV2(4, 1, 3, repLevels, defLevels, PLAIN, data, 4, statsC1P1);
-    w.writeDataPageV2(3, 0, 3, repLevels, defLevels, PLAIN, data, 4, statsC1P2);
+    w.writeDataPageV2(4, 1, 3, repLevels, defLevels, PLAIN, data, false, 4, statsC1P1);
+    w.writeDataPageV2(3, 0, 3, repLevels, defLevels, PLAIN, data, false, 4, statsC1P2);
     w.endColumn();
     long c1Ends = w.getPos();
 
     w.startColumn(C2, 5, CODEC);
     long c2Starts = w.getPos();
-    w.writeDataPageV2(5, 2, 3, repLevels, defLevels, PLAIN, data2, 4, EMPTY_STATS);
-    w.writeDataPageV2(2, 0, 2, repLevels, defLevels, PLAIN, data2, 4, EMPTY_STATS);
+    w.writeDataPageV2(5, 2, 3, repLevels, defLevels, PLAIN, data2, false, 4, EMPTY_STATS);
+    w.writeDataPageV2(2, 0, 2, repLevels, defLevels, PLAIN, data2, false, 4, EMPTY_STATS);
     w.endColumn();
     long c2Ends = w.getPos();
 
@@ -1032,7 +1030,7 @@ public class TestParquetFileWriter {
     File testFile = temp.newFile();
     testFile.delete();
 
-    writeSchema = "message example {\n" + "required binary content (UTF8);\n" + "}";
+    String writeSchema = "message example {\n" + "required binary content (UTF8);\n" + "}";
 
     Path path = new Path(testFile.toURI());
 
@@ -1041,7 +1039,7 @@ public class TestParquetFileWriter {
     configuration.setBoolean("parquet.strings.signed-min-max.enabled", true);
     GroupWriteSupport.setSchema(schema, configuration);
 
-    // close any filesystems to ensure that the the FS used by the writer picks up the configuration
+    // close any filesystems to ensure that the FS used by the writer picks up the configuration
     FileSystem.closeAll();
     ParquetWriter<Group> writer = new ParquetWriter<Group>(path, configuration, new GroupWriteSupport());
 
