@@ -18,15 +18,37 @@
  */
 package org.apache.parquet.hadoop.thrift;
 
+import static org.junit.Assert.assertEquals;
+
 import com.twitter.data.proto.tutorial.thrift.AddressBook;
 import com.twitter.data.proto.tutorial.thrift.Name;
 import com.twitter.data.proto.tutorial.thrift.Person;
 import com.twitter.data.proto.tutorial.thrift.PhoneNumber;
+import java.io.ByteArrayOutputStream;
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Map;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.io.BytesWritable;
-import org.apache.hadoop.mapreduce.*;
+import org.apache.hadoop.mapreduce.InputSplit;
+import org.apache.hadoop.mapreduce.Job;
+import org.apache.hadoop.mapreduce.JobID;
+import org.apache.hadoop.mapreduce.RecordReader;
+import org.apache.hadoop.mapreduce.TaskAttemptContext;
+import org.apache.hadoop.mapreduce.TaskAttemptID;
+import org.apache.hadoop.mapreduce.TaskID;
+import org.apache.parquet.hadoop.api.ReadSupport;
+import org.apache.parquet.hadoop.util.ContextUtil;
+import org.apache.parquet.thrift.test.RequiredListFixture;
+import org.apache.parquet.thrift.test.RequiredMapFixture;
+import org.apache.parquet.thrift.test.RequiredPrimitiveFixture;
+import org.apache.parquet.thrift.test.RequiredSetFixture;
+import org.apache.parquet.thrift.test.StructWithReorderedOptionalFields;
 import org.apache.parquet.thrift.test.compat.MapWithPrimMapValue;
 import org.apache.parquet.thrift.test.compat.MapWithStructMapValue;
 import org.apache.parquet.thrift.test.compat.MapWithStructValue;
@@ -38,17 +60,9 @@ import org.apache.thrift.protocol.TProtocol;
 import org.apache.thrift.protocol.TProtocolFactory;
 import org.apache.thrift.transport.TIOStreamTransport;
 import org.junit.Test;
-import org.apache.parquet.hadoop.api.ReadSupport;
-import org.apache.parquet.hadoop.util.ContextUtil;
-import org.apache.parquet.thrift.test.*;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.io.ByteArrayOutputStream;
-import java.util.*;
-
-import static org.junit.Assert.assertEquals;
-
 public class TestParquetToThriftReadWriteAndProjection {
 
   private static final Logger LOG = LoggerFactory.getLogger(TestParquetToThriftReadWriteAndProjection.class);
@@ -57,56 +71,40 @@ public class TestParquetToThriftReadWriteAndProjection {
   public void testThriftOptionalFieldsWithReadProjectionUsingParquetSchema() throws Exception {
     // test with projection
     Configuration conf = new Configuration();
-    final String readProjectionSchema = "message AddressBook {\n" +
-            "  optional group persons {\n" +
-            "    repeated group persons_tuple {\n" +
-            "      required group name {\n" +
-            "        optional binary first_name;\n" +
-            "        optional binary last_name;\n" +
-            "      }\n" +
-            "      optional int32 id;\n" +
-            "    }\n" +
-            "  }\n" +
-            "}";
+    final String readProjectionSchema = "message AddressBook {\n" + "  optional group persons {\n"
+        + "    repeated group persons_tuple {\n"
+        + "      required group name {\n"
+        + "        optional binary first_name;\n"
+        + "        optional binary last_name;\n"
+        + "      }\n"
+        + "      optional int32 id;\n"
+        + "    }\n"
+        + "  }\n"
+        + "}";
     conf.set(ReadSupport.PARQUET_READ_SCHEMA, readProjectionSchema);
-    TBase toWrite = new AddressBook(
-            Arrays.asList(
-                    new Person(
-                            new Name("Bob", "Roberts"),
-                            0,
-                            "bob.roberts@example.com",
-                            Arrays.asList(new PhoneNumber("1234567890")))));
+    TBase toWrite = new AddressBook(Arrays.asList(new Person(
+        new Name("Bob", "Roberts"),
+        0,
+        "bob.roberts@example.com",
+        Arrays.asList(new PhoneNumber("1234567890")))));
 
-    TBase toRead = new AddressBook(
-            Arrays.asList(
-                    new Person(
-                            new Name("Bob", "Roberts"),
-                            0,
-                            null,
-                            null)));
+    TBase toRead = new AddressBook(Arrays.asList(new Person(new Name("Bob", "Roberts"), 0, null, null)));
     shouldDoProjection(conf, toWrite, toRead, AddressBook.class);
   }
 
   @Test
   public void testPullingInRequiredStructWithFilter() throws Exception {
     final String projectionFilterDesc = "persons/{id};persons/email";
-    TBase toWrite = new AddressBook(
-            Arrays.asList(
-                    new Person(
-                            new Name("Bob", "Roberts"),
-                            0,
-                            "bob.roberts@example.com",
-                            Arrays.asList(new PhoneNumber("1234567890")))));
+    TBase toWrite = new AddressBook(Arrays.asList(new Person(
+        new Name("Bob", "Roberts"),
+        0,
+        "bob.roberts@example.com",
+        Arrays.asList(new PhoneNumber("1234567890")))));
 
-    //Name is a required field, but is projected out. To make the thrift record pass validation, the name field is filled
-    //with empty string
-    TBase toRead = new AddressBook(
-            Arrays.asList(
-                    new Person(
-                            new Name("", ""),
-                            0,
-                            "bob.roberts@example.com",
-                            null)));
+    // Name is a required field, but is projected out. To make the thrift record pass validation, the name field is
+    // filled
+    // with empty string
+    TBase toRead = new AddressBook(Arrays.asList(new Person(new Name("", ""), 0, "bob.roberts@example.com", null)));
     shouldDoProjectionWithThriftColumnFilter(projectionFilterDesc, toWrite, toRead, AddressBook.class);
   }
 
@@ -117,7 +115,8 @@ public class TestParquetToThriftReadWriteAndProjection {
     toWrite.setFieldOne(1);
     toWrite.setFieldTwo(2);
     toWrite.setFieldThree(3);
-    shouldDoProjectionWithThriftColumnFilter(projectionFilter, toWrite, toWrite, StructWithReorderedOptionalFields.class);
+    shouldDoProjectionWithThriftColumnFilter(
+        projectionFilter, toWrite, toWrite, StructWithReorderedOptionalFields.class);
   }
 
   @Test
@@ -125,23 +124,14 @@ public class TestParquetToThriftReadWriteAndProjection {
 
     final String projectionFilterDesc = "persons/name/*";
 
-    TBase toWrite = new AddressBook(
-            Arrays.asList(
-                    new Person(
-                            new Name("Bob", "Roberts"),
-                            0,
-                            "bob.roberts@example.com",
-                            Arrays.asList(new PhoneNumber("1234567890")))));
+    TBase toWrite = new AddressBook(Arrays.asList(new Person(
+        new Name("Bob", "Roberts"),
+        0,
+        "bob.roberts@example.com",
+        Arrays.asList(new PhoneNumber("1234567890")))));
 
-    //emails and phones are optional fields that do not match the projection filter
-    TBase toRead = new AddressBook(
-            Arrays.asList(
-                    new Person(
-                            new Name("Bob", "Roberts"),
-                            0,
-                            null,
-                            null))
-    );
+    // emails and phones are optional fields that do not match the projection filter
+    TBase toRead = new AddressBook(Arrays.asList(new Person(new Name("Bob", "Roberts"), 0, null, null)));
 
     shouldDoProjectionWithThriftColumnFilter(projectionFilterDesc, toWrite, toRead, AddressBook.class);
   }
@@ -196,7 +186,6 @@ public class TestParquetToThriftReadWriteAndProjection {
     return sv4;
   }
 
-
   @Test
   public void testDropMapValueStruct() throws Exception {
     String filter = "reqMap/key";
@@ -224,8 +213,7 @@ public class TestParquetToThriftReadWriteAndProjection {
   public void testDropMapValueNestedPrim() throws Exception {
     String filter = "reqMap/key";
 
-    Map<String, Map<String, String>> mapValue =
-        new HashMap<String, Map<String, String>>();
+    Map<String, Map<String, String>> mapValue = new HashMap<String, Map<String, String>>();
 
     Map<String, String> innerValue1 = new HashMap<String, String>();
     innerValue1.put("inner key (1, 1)", "inner (1, 1)");
@@ -258,7 +246,6 @@ public class TestParquetToThriftReadWriteAndProjection {
     shouldDoProjectionWithThriftColumnFilter(filter, toWrite, toRead, MapWithPrimMapValue.class);
   }
 
-
   @Test
   public void testDropMapValueNestedStruct() throws Exception {
     String filter = "reqMap/key";
@@ -279,13 +266,16 @@ public class TestParquetToThriftReadWriteAndProjection {
 
     MapWithStructMapValue toWrite = new MapWithStructMapValue(mapValue);
 
-    Map<String, Map<String, StructV4WithExtracStructField>> expected = new HashMap<String, Map<String, StructV4WithExtracStructField>>();
+    Map<String, Map<String, StructV4WithExtracStructField>> expected =
+        new HashMap<String, Map<String, StructV4WithExtracStructField>>();
 
-    Map<String, StructV4WithExtracStructField> expectedInnerValue1 = new HashMap<String, StructV4WithExtracStructField>();
+    Map<String, StructV4WithExtracStructField> expectedInnerValue1 =
+        new HashMap<String, StructV4WithExtracStructField>();
     expectedInnerValue1.put("inner key (1, 1)", new StructV4WithExtracStructField("outer name inner (1, 1)"));
     expectedInnerValue1.put("inner key (1, 2)", new StructV4WithExtracStructField("outer name inner (1, 2)"));
 
-    Map<String, StructV4WithExtracStructField> expectedInnerValue2 = new HashMap<String, StructV4WithExtracStructField>();
+    Map<String, StructV4WithExtracStructField> expectedInnerValue2 =
+        new HashMap<String, StructV4WithExtracStructField>();
     expectedInnerValue2.put("inner key (2, 1)", new StructV4WithExtracStructField("outer name inner (2, 1)"));
     expectedInnerValue2.put("inner key (2, 2)", new StructV4WithExtracStructField("outer name inner (2, 2)"));
 
@@ -301,7 +291,8 @@ public class TestParquetToThriftReadWriteAndProjection {
   public void testPullInRequiredLists() throws Exception {
     String filter = "info";
 
-    RequiredListFixture toWrite = new RequiredListFixture(Arrays.asList(new org.apache.parquet.thrift.test.Name("first_name")));
+    RequiredListFixture toWrite =
+        new RequiredListFixture(Arrays.asList(new org.apache.parquet.thrift.test.Name("first_name")));
     toWrite.setInfo("test_info");
 
     RequiredListFixture toRead = new RequiredListFixture(new ArrayList<org.apache.parquet.thrift.test.Name>());
@@ -314,7 +305,8 @@ public class TestParquetToThriftReadWriteAndProjection {
   public void testPullInRequiredSets() throws Exception {
     String filter = "info";
 
-    RequiredSetFixture toWrite = new RequiredSetFixture(new HashSet<org.apache.parquet.thrift.test.Name>(Arrays.asList(new org.apache.parquet.thrift.test.Name("first_name"))));
+    RequiredSetFixture toWrite = new RequiredSetFixture(new HashSet<org.apache.parquet.thrift.test.Name>(
+        Arrays.asList(new org.apache.parquet.thrift.test.Name("first_name"))));
     toWrite.setInfo("test_info");
 
     RequiredSetFixture toRead = new RequiredSetFixture(new HashSet<org.apache.parquet.thrift.test.Name>());
@@ -327,33 +319,38 @@ public class TestParquetToThriftReadWriteAndProjection {
   public void testPullInPrimitiveValues() throws Exception {
     String filter = "info_string";
 
-    RequiredPrimitiveFixture toWrite = new RequiredPrimitiveFixture(true, (byte)2, (short)3, 4, (long)5, (double)6.0, "7");
+    RequiredPrimitiveFixture toWrite =
+        new RequiredPrimitiveFixture(true, (byte) 2, (short) 3, 4, (long) 5, (double) 6.0, "7");
     toWrite.setInfo_string("it's info");
 
-    RequiredPrimitiveFixture toRead = new RequiredPrimitiveFixture(false, (byte)0, (short)0, 0, (long)0, (double)0.0, "");
+    RequiredPrimitiveFixture toRead =
+        new RequiredPrimitiveFixture(false, (byte) 0, (short) 0, 0, (long) 0, (double) 0.0, "");
     toRead.setInfo_string("it's info");
 
     shouldDoProjectionWithThriftColumnFilter(filter, toWrite, toRead, RequiredPrimitiveFixture.class);
   }
 
-  private void shouldDoProjectionWithThriftColumnFilter(String filterDesc, TBase toWrite, TBase toRead, Class<? extends TBase<?, ?>> thriftClass) throws Exception {
+  private void shouldDoProjectionWithThriftColumnFilter(
+      String filterDesc, TBase toWrite, TBase toRead, Class<? extends TBase<?, ?>> thriftClass) throws Exception {
     Configuration conf = new Configuration();
     conf.set(ThriftReadSupport.THRIFT_COLUMN_FILTER_KEY, filterDesc);
     shouldDoProjection(conf, toWrite, toRead, thriftClass);
   }
 
-
-  private <T extends TBase<?, ?>> void shouldDoProjection(Configuration conf, T recordToWrite, T exptectedReadResult, Class<? extends TBase<?, ?>> thriftClass) throws Exception {
+  private <T extends TBase<?, ?>> void shouldDoProjection(
+      Configuration conf, T recordToWrite, T exptectedReadResult, Class<? extends TBase<?, ?>> thriftClass)
+      throws Exception {
     final Path parquetFile = new Path("target/test/TestParquetToThriftReadWriteAndProjection/file.parquet");
     final FileSystem fs = parquetFile.getFileSystem(conf);
     if (fs.exists(parquetFile)) {
       fs.delete(parquetFile, true);
     }
 
-    //create a test file
+    // create a test file
     final TProtocolFactory protocolFactory = new TCompactProtocol.Factory();
     final TaskAttemptID taskId = new TaskAttemptID("local", 0, true, 0, 0);
-    final ThriftToParquetFileWriter w = new ThriftToParquetFileWriter(parquetFile, ContextUtil.newTaskAttemptContext(conf, taskId), protocolFactory, thriftClass);
+    final ThriftToParquetFileWriter w = new ThriftToParquetFileWriter(
+        parquetFile, ContextUtil.newTaskAttemptContext(conf, taskId), protocolFactory, thriftClass);
     final ByteArrayOutputStream baos = new ByteArrayOutputStream();
     final TProtocol protocol = protocolFactory.getProtocol(new TIOStreamTransport(baos));
 
@@ -361,17 +358,19 @@ public class TestParquetToThriftReadWriteAndProjection {
     w.write(new BytesWritable(baos.toByteArray()));
     w.close();
 
-
     final ParquetThriftInputFormat<T> parquetThriftInputFormat = new ParquetThriftInputFormat<T>();
     final Job job = new Job(conf, "read");
     job.setInputFormatClass(ParquetThriftInputFormat.class);
     ParquetThriftInputFormat.setInputPaths(job, parquetFile);
     final JobID jobID = new JobID("local", 1);
-    List<InputSplit> splits = parquetThriftInputFormat.getSplits(ContextUtil.newJobContext(ContextUtil.getConfiguration(job), jobID));
+    List<InputSplit> splits =
+        parquetThriftInputFormat.getSplits(ContextUtil.newJobContext(ContextUtil.getConfiguration(job), jobID));
     T readValue = null;
     for (InputSplit split : splits) {
-      TaskAttemptContext taskAttemptContext = ContextUtil.newTaskAttemptContext(ContextUtil.getConfiguration(job), new TaskAttemptID(new TaskID(jobID, true, 1), 0));
-      try (final RecordReader<Void, T> reader = parquetThriftInputFormat.createRecordReader(split, taskAttemptContext)) {
+      TaskAttemptContext taskAttemptContext = ContextUtil.newTaskAttemptContext(
+          ContextUtil.getConfiguration(job), new TaskAttemptID(new TaskID(jobID, true, 1), 0));
+      try (final RecordReader<Void, T> reader =
+          parquetThriftInputFormat.createRecordReader(split, taskAttemptContext)) {
         reader.initialize(split, taskAttemptContext);
         if (reader.nextKeyValue()) {
           readValue = reader.getCurrentValue();
@@ -381,5 +380,4 @@ public class TestParquetToThriftReadWriteAndProjection {
     }
     assertEquals(exptectedReadResult, readValue);
   }
-
 }
